# The Game of life Emulator
This software is a customizable emulator for [Game of life](https://en.wikipedia.org/wiki/Conway%27s_Game_of_Life).

Simple Usage:

```bash
$ gameoflife --option=value --option=value...
```

To see the help and more information, use `--help` option:

```bash
$ gameoflife --help
```

This project is licensed under [GPL-v3](LICENSE).
